==> libreoffice-fresh-sdk-25.2.3-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.js <==
var interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition =
[
    [ "XDocumentSubStorageSupplier", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a89ee3391a8c42649cd31f02dba97bcde", null ],
    [ "XStorageBasedDocument", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a27754205dcbed856668a7b449beb5e72", null ],
    [ "XViewDataSupplier", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a6d7f982cad4c281309111f133daca065", null ],
    [ "XVisualObject", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a9032f15a756be8739f420497c1f1deea", null ],
    [ "XLoadable", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#ae245282abbbc2cbc054377ed0d60eefc", null ],
    [ "XModel", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a85c12213b20891ad0beb09e95eda4991", null ],
    [ "XStyleFamiliesSupplier", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a8eba31498e63e0ae9f686a0d3b0e1cbc", null ],
    [ "XUIConfigurationManagerSupplier", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a96322b63fbb47f47a9a0e8bf9c08afe3", null ],
    [ "XCloseable", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a149ace20ec88fbb5aa4d00af598f0fdc", null ],
    [ "XModifiable2", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a5ebf44f15658748fb31d36d3c71276d6", null ],
    [ "XFunctionsSupplier", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a3d6339dd517244c36fcfb83b0b9a5db9", null ],
    [ "XReportComponent", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a4eba7fd2195200265b658e6d069dce71", null ],
    [ "getAvailableMimeTypes", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a533ec2fd3450577d3d252add43eb90cd", null ],
    [ "getEventBroadcaster", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#ac3b4f8f2d97be222996aa9b800219b26", null ],
    [ "ActiveConnection", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a765ecad8eb3c9ef970f0d98ef33b54ca", null ],
    [ "Caption", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a2e6868253a3b739acdaa53339eff7a49", null ],
    [ "Command", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a70272cc3797fc39c8a694c651bef53ef", null ],
    [ "CommandType", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a01e54edfb2814946f220267568c3868e", null ],
    [ "DataSourceName", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#ae32b88b27240268a6a5a2fecca03e1df", null ],
    [ "Detail", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a8098bb3a092aaad4a7f15ea0149495c4", null ],
    [ "EscapeProcessing", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#aa71981b851337d3842caede42c842c31", null ],
    [ "Filter", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a36e60b26868092e2acd03532c3dc0549", null ],
    [ "GroupKeepTogether", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a2de96cffb56099a175fc6f1afa5c6ba3", null ],
    [ "Groups", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a5219ad3efcdf39c996a04009eeb27ce1", null ],
    [ "MimeType", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a60fd10355a0ba590ab36a2aaae02455c", null ],
    [ "PageFooter", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#aaa98cabc3eafcd6719c6e0a0d33a4021", null ],
    [ "PageFooterOn", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a3f5bf881cb8a51ef1e27b4da5173a19d", null ],
    [ "PageFooterOption", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#aeceb1bc45a50c21cd18bc666ba857ebd", null ],
    [ "PageHeader", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a36c0eb6983226d60444f451fef7abb9d", null ],
    [ "PageHeaderOn", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#aae336bdae36938f3a1b9f85bc5f6aec6", null ],
    [ "PageHeaderOption", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a156e108cecd4ed739a6bf463b84bdb40", null ],
    [ "ReportFooter", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a9e8a315e5a11929fc09992863e09a508", null ],
    [ "ReportFooterOn", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a6857b22736d8aac7b1f4ca1406d9d28c", null ],
    [ "ReportHeader", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a69898bc15d76086298bd382732483b66", null ],
    [ "ReportHeaderOn", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#acd96031b1a800d55bd10230a8dc01416", null ]
];

==> libreoffice-fresh-sdk-25.8.3-3-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.js <==
var interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition =
[
    [ "com::sun::star::document::XDocumentSubStorageSupplier", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a89ee3391a8c42649cd31f02dba97bcde", null ],
    [ "com::sun::star::document::XStorageBasedDocument", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a27754205dcbed856668a7b449beb5e72", null ],
    [ "com::sun::star::document::XViewDataSupplier", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a6d7f982cad4c281309111f133daca065", null ],
    [ "com::sun::star::embed::XVisualObject", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a9032f15a756be8739f420497c1f1deea", null ],
    [ "com::sun::star::frame::XLoadable", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#ae245282abbbc2cbc054377ed0d60eefc", null ],
    [ "com::sun::star::frame::XModel", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a85c12213b20891ad0beb09e95eda4991", null ],
    [ "com::sun::star::style::XStyleFamiliesSupplier", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a8eba31498e63e0ae9f686a0d3b0e1cbc", null ],
    [ "com::sun::star::ui::XUIConfigurationManagerSupplier", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a96322b63fbb47f47a9a0e8bf9c08afe3", null ],
    [ "com::sun::star::util::XCloseable", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a149ace20ec88fbb5aa4d00af598f0fdc", null ],
    [ "com::sun::star::util::XModifiable2", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a5ebf44f15658748fb31d36d3c71276d6", null ],
    [ "XFunctionsSupplier", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a3d6339dd517244c36fcfb83b0b9a5db9", null ],
    [ "XReportComponent", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a4eba7fd2195200265b658e6d069dce71", null ],
    [ "getAvailableMimeTypes", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a533ec2fd3450577d3d252add43eb90cd", null ],
    [ "getEventBroadcaster", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#ac3b4f8f2d97be222996aa9b800219b26", null ],
    [ "ActiveConnection", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a765ecad8eb3c9ef970f0d98ef33b54ca", null ],
    [ "Caption", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a2e6868253a3b739acdaa53339eff7a49", null ],
    [ "Command", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a70272cc3797fc39c8a694c651bef53ef", null ],
    [ "CommandType", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a01e54edfb2814946f220267568c3868e", null ],
    [ "DataSourceName", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#ae32b88b27240268a6a5a2fecca03e1df", null ],
    [ "Detail", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a8098bb3a092aaad4a7f15ea0149495c4", null ],
    [ "EscapeProcessing", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#aa71981b851337d3842caede42c842c31", null ],
    [ "Filter", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a36e60b26868092e2acd03532c3dc0549", null ],
    [ "GroupKeepTogether", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a2de96cffb56099a175fc6f1afa5c6ba3", null ],
    [ "Groups", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a5219ad3efcdf39c996a04009eeb27ce1", null ],
    [ "MimeType", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a60fd10355a0ba590ab36a2aaae02455c", null ],
    [ "PageFooter", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#aaa98cabc3eafcd6719c6e0a0d33a4021", null ],
    [ "PageFooterOn", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a3f5bf881cb8a51ef1e27b4da5173a19d", null ],
    [ "PageFooterOption", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#aeceb1bc45a50c21cd18bc666ba857ebd", null ],
    [ "PageHeader", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a36c0eb6983226d60444f451fef7abb9d", null ],
    [ "PageHeaderOn", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#aae336bdae36938f3a1b9f85bc5f6aec6", null ],
    [ "PageHeaderOption", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a156e108cecd4ed739a6bf463b84bdb40", null ],
    [ "ReportFooter", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a9e8a315e5a11929fc09992863e09a508", null ],
    [ "ReportFooterOn", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a6857b22736d8aac7b1f4ca1406d9d28c", null ],
    [ "ReportHeader", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#a69898bc15d76086298bd382732483b66", null ],
    [ "ReportHeaderOn", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html#acd96031b1a800d55bd10230a8dc01416", null ]
];
